# Copyright 2004 Rainer Wichmann
# Distributed under the terms of the GNU General Public License v2

inherit eutils

MY_P="${PN}_signed-${PV}"
SLOT="0"
LICENSE="GPL-2"
DESCRIPTION="Samhain is a file integrity checker with optional central logging"

# This is a fake URI that allows us to do a 'make dist' and copy
# the file to distdir. 
# The proper URI would be http://www.la-samhna.de/archive/${MY_P}.tar.gz,
# but this would force us to do a 'make dist-sign' ...
# Apparently, portage cannot handle the file:// scheme,
# and not every user might be prepared to create a signed tarball.
#
# SRC_URI="http://www.la-samhna.de/archive/${MY_P}.tar.gz"
SRC_URI="http://www.la-samhna.de/archive/${P}.tar.gz"


HOMEPAGE="http://www.la-samhna.de/samhain/"

KEYWORDS="x86"

IUSE=""

DEPEND="app-arch/gzip
	app-arch/tar"
#	mysql? (>=dev-db/mysql-3.23.58)"
RDEPEND=""

src_unpack() {
        unpack ${A}
        cd ${WORKDIR}
        if test -f ${P}.tar.gz; then
	   gunzip -c ${P}.tar.gz | tar xf -  || die
	   cd ${P}
	elif test -d "samhain-${PV}"; then
	   mv "samhain-${PV}" "samhain-${PV}"
	fi
}

src_compile() {
	local myconf="--with-trusted=0,250"

#	myconf="$myconf --enable-mounts-check"
#	myconf="$myconf --enable-userfiles"

#	use mysql    && myconf="$myconf --with-database=mysql"
#	use postgres && myconf="$myconf --with-database=postgresql"

#        econf \
#	      --with-pid-file=/var/run/${PN}.pid \
#	      --with-state-dir=/var/lib/${PN} \
#	      --with-log-file=/var/log/${PN}.log \

	./configure ${myconf} --enable-base=,  '--build=x86_64-linux' '--host=arm-nilrt-linux-gnueabi' '--target=arm-nilrt-linux-gnueabi' '--prefix=/usr' '--exec_prefix=/usr' '--bindir=/usr/bin' '--sbindir=/usr/sbin' '--libexecdir=/usr/libexec' '--datadir=/usr/share' '--sysconfdir=/etc' '--sharedstatedir=/com' '--localstatedir=/var' '--libdir=/usr/lib' '--includedir=/usr/include' '--infodir=/usr/share/info' '--mandir=/usr/share/man' '--enable-network=client' '--with-pid-file=/var/run/samhain.pid' '--with-data-file=/var/lib/samhain/samhain_file' '--with-logserver=NULL' '--with-port=49777' '--disable-posix-acl' 'ac_cv_header_auparse_h=yes' '--enable-ipv6' '--with-database=postgresql' '--enable-xml-log' 'PGSQL_INC_DIR=/srv/jenkins/perforce/ThirdPartyExports/NIOpenEmbedded/trunk/8.7/objects/feed/linuxU/armv7-a/gcc-4.7-oe/release/build/tmp-glibc/work/cortexa9-vfpv3-nilrt-linux-gnueabi/samhain-client/4.2.2-r0/recipe-sysroot/usr/include' 'PGSQL_LIB_DIR=/srv/jenkins/perforce/ThirdPartyExports/NIOpenEmbedded/trunk/8.7/objects/feed/linuxU/armv7-a/gcc-4.7-oe/release/build/tmp-glibc/work/cortexa9-vfpv3-nilrt-linux-gnueabi/samhain-client/4.2.2-r0/recipe-sysroot/usr/lib' '--with-ps-path=/bin/ps' '--enable-selinux' 'build_alias=x86_64-linux' 'host_alias=arm-nilrt-linux-gnueabi' 'target_alias=arm-nilrt-linux-gnueabi' 'CC=arm-nilrt-linux-gnueabi-gcc  -march=armv7-a -mfpu=vfpv3 -mfloat-abi=softfp -mcpu=cortex-a9 --sysroot=/srv/jenkins/perforce/ThirdPartyExports/NIOpenEmbedded/trunk/8.7/objects/feed/linuxU/armv7-a/gcc-4.7-oe/release/build/tmp-glibc/work/cortexa9-vfpv3-nilrt-linux-gnueabi/samhain-client/4.2.2-r0/recipe-sysroot' 'CFLAGS= -O2 -pipe -g -feliminate-unused-debug-types -fdebug-prefix-map=/srv/jenkins/perforce/ThirdPartyExports/NIOpenEmbedded/trunk/8.7/objects/feed/linuxU/armv7-a/gcc-4.7-oe/release/build/tmp-glibc/work/cortexa9-vfpv3-nilrt-linux-gnueabi/samhain-client/4.2.2-r0=/usr/src/debug/samhain-client/4.2.2-r0 -fdebug-prefix-map=/srv/jenkins/perforce/ThirdPartyExports/NIOpenEmbedded/trunk/8.7/objects/feed/linuxU/armv7-a/gcc-4.7-oe/release/build/tmp-glibc/work/cortexa9-vfpv3-nilrt-linux-gnueabi/samhain-client/4.2.2-r0/recipe-sysroot= -fdebug-prefix-map=/srv/jenkins/perforce/ThirdPartyExports/NIOpenEmbedded/trunk/8.7/objects/feed/linuxU/armv7-a/gcc-4.7-oe/release/build/tmp-glibc/work/cortexa9-vfpv3-nilrt-linux-gnueabi/samhain-client/4.2.2-r0/recipe-sysroot-native= ' 'LDFLAGS=-Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed' 'CPPFLAGS=' 'CPP=arm-nilrt-linux-gnueabi-gcc -E --sysroot=/srv/jenkins/perforce/ThirdPartyExports/NIOpenEmbedded/trunk/8.7/objects/feed/linuxU/armv7-a/gcc-4.7-oe/release/build/tmp-glibc/work/cortexa9-vfpv3-nilrt-linux-gnueabi/samhain-client/4.2.2-r0/recipe-sysroot  -march=armv7-a -mfpu=vfpv3 -mfloat-abi=softfp -mcpu=cortex-a9' || die
        emake || die

	echo '#!/bin/sh' > ./sstrip
	echo 'echo "*** SSTRIP DISABLED ***"' >> ./sstrip
}

src_install() {
        make DESTDIR=${D} install  || die
        make DESTDIR=${D} install-boot  || die

	dodoc docs/BUGS COPYING docs/Changelog LICENSE docs/README \
	      docs/README.UPGRADE docs/sh_mounts.txt docs/sh_userfiles.txt \
	      docs/MANUAL-2_4.ps docs/MANUAL-2_4.html.tar

	dohtml docs/HOWTO-client+server.html docs/HOWTO-samhain+GnuPG.html \
	       docs/HOWTO-write-modules.html docs/HOWTO-samhain-on-windows.html \
	       docs/HOWTO-client+server-troubleshooting.html docs/FAQ.html 
}

pkg_prerm() {
	rc-update del samhain
	einfo "Stopping service samhain"
	test -f /etc/init.d/samhain && /etc/init.d/samhain stop
	sleep 3
}

pkg_postinst() {
	rc-update add samhain default
	einfo
        einfo "samhain is installed but is NOT running yet, and the database"
	einfo "of file signatures is NOT initialized yet."
	einfo
	einfo "You need to run \"samhain -t init\" to initialize "
        einfo "the baseline database of file signatures."
        einfo
	einfo "After initializing the database, you can start samhain "
	einfo "with \"/etc/init.d/samhain start\". It is configured to start"
	einfo "automatically on the next boot for runlevel \"default\""
}	      

